@@ -1,6 +1,7 @@
 /* bjnp-debug.c
  *
  * (c) 2008, 2009 Louis Lagendijk
+ * (c) 2018 Markus Heinz
  *
  * This software is licensed under the terms of the GPL.
  * For details see file COPYING.
@@ -14,7 +15,6 @@
 #include <string.h>
 
 #include <sys/time.h>
-#include <sys/timeb.h>
 
 #include <unistd.h>		/* usleep */
 #include <stdint.h>
@@ -58,7 +58,7 @@ static bjnp_loglevel_t debug_level = LOG_ERROR;
 static int to_cups = 0;
 static FILE *debug_file = NULL;
 static time_t start_sec = 0;
-static int start_msec;
+static suseconds_t start_msec;
 
 /* 
  * local functions
@@ -189,7 +189,7 @@ bjnp_debug (bjnp_loglevel_t level, const char *fmt, ...)
 {
   va_list ap;
   char printbuf[256];
-  struct timeb timebuf;
+  struct timeval tp;
   int sec;
   int msec;
 
@@ -207,14 +207,15 @@ bjnp_debug (bjnp_loglevel_t level, const char *fmt, ...)
 
   if ((level <= debug_level) && debug_file)
     {
-      ftime (&timebuf);
-      if ((msec = timebuf.millitm - start_msec) < 0)
-	{
-	  msec += 1000;
-	  timebuf.time -= 1;
-	}
-      sec = timebuf.time - start_sec;
+      gettimeofday(&tp, NULL);
 
+      if ((msec = tp.tv_usec - start_msec) < 0) {
+        msec += 1000;
+        tp.tv_sec -= 1;
+      }
+      
+      sec = tp.tv_sec - start_sec;
+      
       fprintf (debug_file, "%s: %03d.%03d %s", level2str (level), sec, msec,
 	       printbuf);
     }
@@ -227,14 +228,14 @@ bjnp_set_debug_level (char *level)
    * set debug level to level (string)
    */
 
-  struct timeb timebuf;
+  struct timeval tp;
   char loglevel[16];
   char *separator;
 
-  ftime (&timebuf);
-  start_sec = timebuf.time;
-  start_msec = timebuf.millitm;
-
+  gettimeofday(&tp, NULL);
+  start_sec = tp.tv_sec;
+  start_msec = tp.tv_usec;
+  
   /*
    * Split string into loglevel and optional cupslog string
    */
