@@ -1,6 +1,6 @@
 /* devices.c
  *
- * (c) 2015, 2018 Markus Heinz
+ * (c) 2015, 2018, 2022 Markus Heinz
  *
  * This software is licensed under the terms of the GPL.
  * For details see file COPYING.
@@ -27,14 +27,13 @@ int get_device_id(const int port, const char *device_file,
   int result = COULD_NOT_GET_DEVICE_ID;
 
   if (port == USB) {
-    libusb_context *ctx = NULL;
     usb_printer *printer = NULL;
 
-    if (init_usb(ctx) != USB_SUCCESS) {
+    if (init_usb() != USB_SUCCESS) {
       return COULD_NOT_GET_DEVICE_ID;
     }
 
-    printer = find_printer(ctx, portnumber);
+    printer = find_printer(portnumber);
 
     if (printer != NULL) {
       result = open_device_handle(printer);
@@ -47,7 +46,7 @@ int get_device_id(const int port, const char *device_file,
       free(printer);
     }
 
-    shutdown_usb(ctx);
+    shutdown_usb();
 
     if (result == USB_SUCCESS)
       return OK;
